<?php        
/**
 * Guardian functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Guardian
 */
	require( get_template_directory() . '/class-tgm-plugin-activation.php' );
	/* Menus */
	require( get_template_directory() . '/core/menu/default_menu_walker.php' ); 	
	require( get_template_directory() . '/core/menu/weblizar_nav_walker.php' ); 
	
	require( get_template_directory() . '/core/comment-function.php' );	
	require( get_template_directory() . '/core/custom-header.php' );	
	require get_template_directory() . '/upgrade-to-pro/class-customize.php';
	/* Get the plugin */
	if ( ! function_exists( 'guardian_theme_is_weblizar_companion_active' ) ) {
	    function guardian_theme_is_weblizar_companion_active() {
	        require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	        if ( is_plugin_active(  'weblizar-companion/IS-theme-companion.php' ) ) {
	            return true;
	        } else {
	            return false;
	        }
	    }
	} 
		
	/* After Theme Setup */
	add_action( 'after_setup_theme', 'guardian_setup' ); 	
	function guardian_setup() {	

		add_theme_support( 'title-tag' );
		
		/* Woocommerce */
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-zoom' );
	    add_theme_support( 'wc-product-gallery-lightbox' );
	    add_theme_support( 'wc-product-gallery-slider' );

		global $content_width;
		//content width
		if ( ! isset( $content_width ) ) $content_width = 630; //px
	
		// Load text domain for translation-ready
		load_theme_textdomain( 'guardian', get_template_directory() . '/core/lang' );
		add_theme_support( 'post-thumbnails' ); //supports featured image
		
		// This theme uses wp_nav_menu() in one location.
		register_nav_menu( 'primary', __( 'Primary Menu', 'guardian' ) );
		add_theme_support( 'customize-selective-refresh-widgets' );

		/* Gutenberg */
		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'align-wide' );

		/* Add editor style */
		add_theme_support( 'editor-styles' );
		add_theme_support( 'dark-editor-style' );

		/* Allow shortcodes in widgets. */
		add_filter( 'widget_text', 'do_shortcode' );
		
		// Logo
		add_theme_support( 'custom-logo', array(
			'width'       => 250,
			'height'      => 250,
			'flex-width'  => true,
			'flex-height' => true,
			'header-text' => array( 'site-title', 'site-description' ),
		));
			
		// theme support 	
		add_theme_support( 'automatic-feed-links'); 

		$args = array( 
			'default-color' => 'fff' 
		);
		add_theme_support( 'custom-background', $args );
		add_editor_style( 'editor-style.css' );
		add_theme_support( "responsive-embeds" );
		add_theme_support( "html5", $args );
			
		//About-Us Post Thumb
		add_image_size('guardian_about_post_thumb',1140, 380,true);
		//Blogs thumbs
		add_image_size('guardian_home_post_thumb',360,180,true);	
		add_image_size('guardian_wl_page_thumb',730,350,true);
		add_image_size('guardian_wl_pageff_thumb',1170,350,true);
		add_image_size('guardian_small_thumbs',1170,520,true); //2-Column
		add_image_size('guardian_recent_blog_img',64,64,true);	
	}

	/* excerpt length */
	function guardian_excerpt_length( $length ) {
		if ( is_admin() ) return $length; return 30;
	}
	add_filter( 'excerpt_length', 'guardian_excerpt_length' );
	
	/* guardian widget area */
	add_action( 'widgets_init', 'guardian_widgets_init');
	function guardian_widgets_init() {
		/* sidebar */
		register_sidebar( array(
			'name'          => __( 'Sidebar', 'guardian' ),
			'id'            => 'sidebar-primary',
			'description'   => __( 'The primary widget area', 'guardian' ),
			'before_widget' => '<div id="%1$s" class="col-md-12 sidebar_widget %2$s">',
			'after_widget'  => '</div><div class="clearfix margin_top3"></div>',
			'before_title'  => '<div class="col-md-12 sidebar_title"><h4>',
			'after_title'   => '</h4></div>'
		) );
		/* footer widget area */
		register_sidebar( array(
			'name'          => __( 'Footer Widget Area', 'guardian' ),
			'id'            => 'footer-widget-area',
			'description'   => __( 'footer widget area', 'guardian' ),
			'before_widget' => '<div id="%1$s" class="col-md-3 one_fourth animate fadeInUp %2$s" data-anim-type="fadeInUp"><div class="qlinks">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h4 class="lmb">',
			'after_title'   => '</h4>',
		) );             
	}
	
	/* Guardian theme css and js */
	function guardian_scripts() {	
		// Google fonts 	
		 wp_enqueue_style('OpenSansRegular','//fonts.googleapis.com/css?family=Open+Sans');
                 wp_enqueue_style('OpenSansBold','//fonts.googleapis.com/css?family=Open+Sans:700');
                 wp_enqueue_style('OpenSansSemiBold','//fonts.googleapis.com/css?family=Open+Sans:600');
                 wp_enqueue_style('RobotoRegular','//fonts.googleapis.com/css?family=Roboto');
		 wp_enqueue_style('RobotoBold','//fonts.googleapis.com/css?family=Roboto:700');
		 wp_enqueue_style('RalewaySemiBold','//fonts.googleapis.com/css?family=Raleway:600');
		 wp_enqueue_style('Courgette','//fonts.googleapis.com/css?family=Courgette');
		
		/* css */
		wp_enqueue_style( 'stylesheet', get_template_directory_uri() . '/style.css'); 
		wp_enqueue_style( 'font-awesome-581', get_template_directory_uri(). '/css/font-awesome-5.8.1/css/all.css');
		
		wp_enqueue_style( 'guardian-responsive-leyouts', get_template_directory_uri() . '/css/responsive-leyouts.css');
		wp_enqueue_style( 'bootstrap-css', get_template_directory_uri() . '/css/bootstrap.css');		
		wp_enqueue_style( 'guardian-menu', get_template_directory_uri() . '/css/menu.css');
		wp_enqueue_style( 'guardian-sticky', get_template_directory_uri() . '/css/sticky.css');
		wp_enqueue_style( 'swiper-css', get_template_directory_uri() . '/css/swiper.css');
		wp_enqueue_style( 'guardian-theme-animtae-css', get_template_directory_uri() . '/css/theme-animtae.css');
		wp_enqueue_style( 'guardian-reset', get_template_directory_uri() . '/css/reset.css');		
		// carousel Slider
		wp_enqueue_style( 'carousel-css', get_template_directory_uri() . '/css/carousel.css');
		
		// Js
		wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() .'/js/bootstrap.js',array( 'jquery' ), true, true );	
		wp_enqueue_script( 'guardian-menu-js', get_template_directory_uri() .'/js/menu.js', array( 'jquery' ), true, true );	
		wp_enqueue_script( 'swiper-js', get_template_directory_uri() .'/js/swiper.js', array( 'jquery' ), true, true );	
		wp_enqueue_script( 'guardian-custom-js', get_template_directory_uri() .'/js/custom.js', array( 'jquery' ), true, true );
		
		// code //
		if ( ! empty ( get_theme_mod('guardian_slider') ) &&  get_theme_mod('guardian_slider') == '1' ) {
                $guardian_slider = true;
        } else {
                $guardian_slider = false;
        }

        $ajax_data = array(
                'guardian_slider' => $guardian_slider,
                'image_speed'     => get_theme_mod('slider_image_speed','2000'),
        );

        wp_enqueue_script( 'guardian-ajax-front', get_template_directory_uri() . '/js/guardian-ajax-front.js', array( 'jquery' ), true, true );
        wp_localize_script( 'guardian-ajax-front', 'ajax_admin', array(
                'ajax_url'    => admin_url( 'admin-ajax.php' ),
                'admin_nonce' => wp_create_nonce( 'admin_ajax_nonce' ),
                'ajax_data'   => $ajax_data,
        ) );

		if ( is_singular() ) wp_enqueue_script( "comment-reply" ); 	
	}
	add_action('wp_enqueue_scripts', 'guardian_scripts');
	
	/* Add Class Gravtar */
	add_filter( 'get_avatar', 'guardian_gravatar_class' );
	function guardian_gravatar_class( $class ) {
	    $class = str_replace( "class='avatar", "class='author_detail_img", $class );
	    return $class;
	}
	
	/* Navigation for Single */
	function guardian_navigation_posts(){ ?>	
		<nav id="wblizar_nav">
			<span class="nav-previous"><?php previous_post_link('&laquo; %link'); ?></span>
			<span class="nav-next"><?php next_post_link('%link &raquo;'); ?></span> 
		</nav><?php 
	}
	/* Breadcrumbs  */
	function guardian_breadcrumbs() {
	    $guardian_delimiter = '';
	    $guardian_home      = __('Home','guardian'); // text for the 'Home' link
	    $guardian_before    = ''; // tag before the current crumb
	    $guardian_after     = ''; // tag after the current crumb
	    echo '<div class="pagenation">';
	    global $post;
	    $guardian_homeLink = esc_url(home_url());
	    echo '<a href="' . esc_url($guardian_homeLink) . '">' . esc_html($guardian_home) . '</a> <i>/</i>' . esc_html($guardian_delimiter) . ' ';
	    if (is_category()) {
	        global $wp_query;
	        $guardian_cat_obj = $wp_query->get_queried_object();
	        $guardian_cat_obj = $guardian_cat_obj->term_id;
	        $guardian_cat_obj = get_category($guardian_cat_obj);
	        $guardian_cat_obj = get_category($guardian_cat_obj->parent);
	        if ($guardian_cat_obj->parent != 0)
	            echo( esc_html(get_category_parents($guardian_cat_obj, TRUE, ' ' . esc_html($guardian_delimiter) . ' ')));
	        echo esc_html($guardian_before) . esc_html__('Archive by category "','guardian') . single_cat_title('', false) . '"' . esc_html($guardian_after);
	    } elseif (is_day()) {
	        echo '<a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . esc_html(get_the_time('Y')) . '</a> <i>/</i> ' . esc_html($guardian_delimiter) . ' ';
	        echo '<a href="' . esc_url(get_month_link(get_the_time('Y'), get_the_time('m'))) . '">' . esc_html(get_the_time('F')) . '</a> <i>/</i> ' . esc_html($guardian_delimiter) . ' ';
	        echo esc_html($guardian_before) . esc_html(get_the_time('d')) . esc_html($guardian_after);
	    } elseif (is_month()) {
	        echo '<a href="' . esc_url(get_year_link(get_the_time('Y'))) . '">' . esc_html(get_the_time('Y')) . '</a> <i>/</i>' . esc_html($guardian_delimiter) . ' ';
	        echo esc_html($guardian_before) . esc_html(get_the_time('F')) . esc_html($guardian_after);
	    } elseif (is_year()) {
	        echo esc_html($guardian_before) . esc_html(get_the_time('Y')) . esc_html($guardian_after);
	    } elseif (is_single() && !is_attachment()) {
	        if (get_post_type() != 'post') {
	            $guardian_post_type = get_post_type_object(get_post_type());
	            $guardian_slug = $guardian_post_type->rewrite;
	            echo '<a href="' . esc_url($guardian_homeLink) . '/' . esc_url($guardian_slug['slug']) . '/">' . esc_html($guardian_post_type->labels->singular_name) . '</a> <i>/</i> ' . esc_html($guardian_delimiter) . ' ';
	            echo esc_html($guardian_before) . esc_html(get_the_title()) . esc_html($guardian_after);
	        } else {
	            $guardian_cat = get_the_category();
	            $guardian_cat = $guardian_cat[0];
	            //echo get_category_parents($guardian_cat, TRUE, ' ' . $guardian_delimiter . ' ');
	            echo esc_html($guardian_before) . esc_html(get_the_title()) . esc_html($guardian_after);
	        }
	    } elseif (!is_single() && !is_page() && get_post_type() != 'post') {
	        $guardian_post_type = get_post_type_object(get_post_type());
			$guardian_count_posts = wp_count_posts()->publish;
			if($guardian_count_posts != '') {
	        echo esc_html($guardian_before) . esc_html($guardian_post_type->labels->singular_name) . esc_html($guardian_after);
			}
	    } elseif (is_attachment()) {
	        $guardian_parent = get_post($post->post_parent);
	        $guardian_cat = get_the_category($guardian_parent->ID);
	        $guardian_cat = $guardian_cat[0];
	        echo esc_html(get_category_parents($guardian_cat, TRUE, ' ' . esc_html($guardian_delimiter) . ' '));
	        echo '<a href="' . esc_url(get_permalink($guardian_parent)) . '">' . esc_html($guardian_parent->post_title) . '</a> <i>/</i> ' . esc_html($guardian_delimiter) . ' ';
	        echo esc_html($guardian_before) . esc_html(get_the_title()) . esc_html($guardian_after);
	    } elseif (is_page() && !$post->post_parent) {
	        echo esc_html($guardian_before) . esc_html(get_the_title()) . esc_html($guardian_after);
	    } elseif (is_page() && $post->post_parent) {
	        $guardian_parent_id = $post->post_parent;
	        $guardian_breadcrumbs = array();
	        while ($guardian_parent_id) {
	            $page = get_page($guardian_parent_id);
	            $guardian_breadcrumbs[] = '<a href="' . esc_url(get_permalink($page->ID)) . '">' .esc_html( get_the_title($page->ID)) . '</a> <i>/</i>';
	            $guardian_parent_id = $page->post_parent;
	        }
	        $guardian_breadcrumbs = array_reverse($guardian_breadcrumbs);
	        foreach ($guardian_breadcrumbs as $guardian_crumb)
	            echo wp_kses_post($guardian_crumb) . ' ' . esc_html($guardian_delimiter) . ' ';
	        echo esc_html($guardian_before) . esc_html(get_the_title()) . esc_html($guardian_after);
	    } elseif (is_search()) {
	        echo esc_html($guardian_before) . esc_html__('Search results for ','guardian') . get_search_query() . '"' . esc_html($guardian_after);
	    } elseif (is_tag()) {
	        echo esc_html($guardian_before) . esc_html__('Posts tagged "','guardian') . single_tag_title('', false) . '"' . esc_html($guardian_after);
	    } elseif (is_author()) {
	        global $author;
	        $guardian_userdata = get_userdata($author);
	        echo esc_html($guardian_before) . esc_html__('Articles posted by ','guardian') . esc_html($guardian_userdata->display_name) . esc_html($guardian_after);
	    } elseif (is_404()) {
	        echo esc_html($guardian_before) . esc_html__('Error 404','guardian') . esc_html($guardian_after);
	    }
	    if (get_query_var('paged')) {
	        if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author())
	            echo ' (';
	        //echo esc_html__('Page', 'guardian') . ' ' . get_query_var('paged');
	        if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author())
	            echo ')';
	    }
	    echo '</div>';
	}

//Plugin Recommend
add_action('tgmpa_register','guardian_plugin_recommend');
function guardian_plugin_recommend(){
	$guardian_plugins = array(
	array(
            'name'      => 'IS-theme-companion',
            'slug'      => 'weblizar-companion',
            'required'  => false,
        )
	);
    tgmpa( $guardian_plugins );
}

if ( is_admin() ) {
	require_once('core/admin/admin-themes.php');
}

add_action( 'wp_enqueue_scripts', 'guardian_custom_css' );
function guardian_custom_css() {
    $guardian_output = '';
	// custom css
	if ( get_theme_mod('custom_css') ) { 
		$guardian_output .= get_theme_mod('custom_css') . "\n";
	}
}